#!/bin/bash

# GPL, mimooh at pld-linux.org
# MODULES_CONFIG set in pldconf_functions

backup_file $MODULES_CONFIG
install_if_missing alsa 

HEADER="# --- BEGIN: Generated by ALSACONF, do not edit. ---"
FOOTER="# --- END: Generated by ALSACONF, do not edit. ---"

generate_config() {
	# removing ALSA entries from /etc/modules.conf or /etc/modprobe.conf and generating new config
	drop_section "$HEADER" "$FOOTER" $MODULES_CONFIG 
	cat >> $MODULES_CONFIG << EOF
$HEADER
alias char-major-116 snd
alias snd-card-0 $module
alias char-major-14 soundcore
alias sound-slot-0 snd-card-0
alias sound-service-0-0 snd-mixer-oss
alias sound-service-0-1 snd-seq-oss
alias sound-service-0-3 snd-pcm-oss
alias sound-service-0-8 snd-seq-oss
alias sound-service-0-12 snd-pcm-oss
options snd major=116 cards_limit=1 device_mode=0660
options $module index=0
$FOOTER
EOF
}

# create alsa modules db
TMPFILE=`mktemp /tmp/pldconf.XXXXXX` || exit
cat /lib/modules/`uname -r`/modules.pcimap | grep ^snd- | while read module id1_ id2_ rest; do
	id1=`echo $id1_ | cut -b7-10`
	id2=`echo $id2_ | cut -b7-10`
	echo "$module $id1$id2" >> $TMPFILE
done

# find the module
cat /proc/bus/pci/devices | while read junk dev rest; do
	cat $TMPFILE | while read module id; do
		if [ "$id" = "$dev" ]; then
			echo "modu ALSA: $module"; sleep 1
			generate_config
		fi
	done
done

${DATA_DIR}/DEVICES/ALSA/alsa_snddevices.sh 1>&2 >/dev/null

cat << EOF

$(nls "Provide user names (separated by spaces) that will have access to audio
devices (they will be added to audio group)
press <enter> if not adding any users")
EOF

read audio_users

for user in $audio_users; do
	add_user_to_group $user audio
done

show_message "$(nls "Global mixer configuration...")"
aumix -m 0 -v 60 -w 60 # set pcm & master to 60, micro to 0
aumix -I -f /etc/aumixrc
line_replace "aumix" "aumix -L >/dev/null" /etc/profile

echo "depmod -a..."
/etc/rc.d/init.d/alsasound restart
depmod -a 2>/dev/null &
${DATA_DIR}/DEVICES/device_menu.sh
